@@ -33,9 +33,10 @@
 #  define KIOFILEWIDGETS_DEPRECATED_NO_EXPORT KIOFILEWIDGETS_NO_EXPORT KIOFILEWIDGETS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KIOFILEWIDGETS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KIOFILEWIDGETS_NO_DEPRECATED
+#    define KIOFILEWIDGETS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
