@@ -33,9 +33,10 @@
 #  define KIOWIDGETS_DEPRECATED_NO_EXPORT KIOWIDGETS_NO_EXPORT KIOWIDGETS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KIOWIDGETS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KIOWIDGETS_NO_DEPRECATED
+#    define KIOWIDGETS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
